@@ -5,7 +5,7 @@
    Author: Mirko Boehm
    Copyright: (C) 2005-2014 Mirko Boehm
    Contact: mirko@kde.org
-         http://www.kde.org
+         https://www.kde.org
          http://creative-destruction.me
 
    This library is free software; you can redistribute it and/or
@@ -34,7 +34,7 @@ class ImageListFilter : public QSortFilterProxyModel {
     Q_OBJECT
 public:
     explicit ImageListFilter(Image::Steps step, QObject* parent = nullptr);
-    bool filterAcceptsRow(int source_row, const QModelIndex & source_parent) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int source_row, const QModelIndex & source_parent) const override;
 private:
     Image::Steps m_step;
 };
